==> keycloak-model-map-18.0.0-sources.jar: org/keycloak/models/map/user/MapUserCredentialEntityFieldDelegate.java <==
package org.keycloak.models.map.user;
public class MapUserCredentialEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.user.MapUserCredentialEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.user.MapUserCredentialEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.user.MapUserCredentialEntity> entityFieldDelegate;
    public MapUserCredentialEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.user.MapUserCredentialEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.user.MapUserCredentialEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserCredentialEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserCredentialEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getType() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserCredentialEntityFields.TYPE);
    }
    @SuppressWarnings("unchecked") @Override public void setType(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserCredentialEntityFields.TYPE, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getUserLabel() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserCredentialEntityFields.USER_LABEL);
    }
    @SuppressWarnings("unchecked") @Override public void setUserLabel(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserCredentialEntityFields.USER_LABEL, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getCreatedDate() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserCredentialEntityFields.CREATED_DATE);
    }
    @SuppressWarnings("unchecked") @Override public void setCreatedDate(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserCredentialEntityFields.CREATED_DATE, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getSecretData() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserCredentialEntityFields.SECRET_DATA);
    }
    @SuppressWarnings("unchecked") @Override public void setSecretData(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserCredentialEntityFields.SECRET_DATA, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getCredentialData() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserCredentialEntityFields.CREDENTIAL_DATA);
    }
    @SuppressWarnings("unchecked") @Override public void setCredentialData(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserCredentialEntityFields.CREDENTIAL_DATA, p0);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/user/MapUserCredentialEntityFieldDelegate.java <==
package org.keycloak.models.map.user;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapUserCredentialEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.user.MapUserCredentialEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.user.MapUserCredentialEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.user.MapUserCredentialEntity> entityFieldDelegate;
    public MapUserCredentialEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.user.MapUserCredentialEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.user.MapUserCredentialEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserCredentialEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserCredentialEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getType() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserCredentialEntityFields.TYPE);
    }
    @SuppressWarnings("unchecked") @Override public void setType(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserCredentialEntityFields.TYPE, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getUserLabel() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserCredentialEntityFields.USER_LABEL);
    }
    @SuppressWarnings("unchecked") @Override public void setUserLabel(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserCredentialEntityFields.USER_LABEL, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getCreatedDate() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserCredentialEntityFields.CREATED_DATE);
    }
    @SuppressWarnings("unchecked") @Override public void setCreatedDate(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserCredentialEntityFields.CREATED_DATE, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getSecretData() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserCredentialEntityFields.SECRET_DATA);
    }
    @SuppressWarnings("unchecked") @Override public void setSecretData(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserCredentialEntityFields.SECRET_DATA, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getCredentialData() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserCredentialEntityFields.CREDENTIAL_DATA);
    }
    @SuppressWarnings("unchecked") @Override public void setCredentialData(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserCredentialEntityFields.CREDENTIAL_DATA, p0);
    }
}
